Learn R Programming

yummlyr (version 0.1.1)

get_recipe: Get recipe from Yummly.com

Description

This call is equivalent in functionality to a Yummly recipe page.

Usage

get_recipe(recipe_id, app_id = auth_cache$APP_ID, app_key = auth_cache$APP_KEY)

Arguments

recipe_id
recipe ID
app_id
application ID
app_key
application KEY

References

Examples

Run this code
## Not run: 
# # to request the response for French Onion Soup by Ree Drummond The Pioneer Woman 
# # with id French-Onion-Soup-The-Pioneer-Woman-Cooks-_-Ree-Drummond-41364
# get_recipe("French-Onion-Soup-The-Pioneer-Woman-Cooks-_-Ree-Drummond-41364")
# ## End(Not run)

Run the code above in your browser using DataLab