Learn R Programming

yummlyr (version 0.1.1)

save_yummly_credentials: Save API credentials for later use

Description

This functions caches the credentials to avoid need for entering it when calling other functions

Usage

save_yummly_credentials(app_id, app_key)

Arguments

app_id
application ID
app_key
application key

Examples

Run this code
# since not checking is preformed not to waste API calls
# it falls on the user to save correct information
save_yummly_credentials("APP_ID", "APP_KEY")

Run the code above in your browser using DataLab