powered by
save_yummly_credentials(app_id, app_key)
# since not checking is preformed not to waste API calls # it falls on the user to save correct information save_yummly_credentials("APP_ID", "APP_KEY")
Run the code above in your browser using DataLab